==> blancoMessage-0.4.0-src.zip: blancoMessage/blanco.cs/main/blanco/message/message/BlancoMessageMessage.cs <==
// ̃\[XR[h blanco FrameworkɂĎĂ܂B
using System;

namespace blanco.message.message
{
    /// <summary>blancoMessageIɗp郁bZ[WNXłB</summary>
    public class BlancoMessageMessage
    {
        /// <summary>[bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B]</summary>
        /// <remarks>
        /// <newpara>No.2: </newpara>
        /// </remarks>
        public static readonly string MBMSGI01 = "[MBMSGI01] bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B";

        /// <summary>[T|[gȂo̓vO~Oꏈn[{0}]w肳܂B]</summary>
        /// <remarks>
        /// <newpara>No.3: </newpara>
        /// </remarks>
        public static readonly string MBMSGI02 = "[MBMSGI02] T|[gȂo̓vO~Oꏈn[{0}]w肳܂B";

        /// <summary>[bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B]</summary>
        /// <remarks>
        /// <newpara>No.4: </newpara>
        /// </remarks>
        public static readonly string MBMSGI03 = "[MBMSGI03] bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B";

        /// <summary>[bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB]</summary>
        /// <remarks>
        /// <newpara>No.5: </newpara>
        /// </remarks>
        public static readonly string MBMSGI04 = "[MBMSGI04] bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB";

        /// <summary>[^fBNg[{0}]݂܂B]</summary>
        /// <remarks>
        /// <newpara>No.8: </newpara>
        /// </remarks>
        public static readonly string MBMSGA01 = "[MBMSGA01] ^fBNg[{0}]݂܂B";

        /// <summary>bZ[W`ID[BlancoMessage]AL[[MBMSGI01]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.2: </newpara>
        /// <newpara>[bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B]</newpara>
        /// </remarks>
        /// <param name="arg0">u{0}̒lB</param>
        /// <returns>bZ[WB</returns>
        public string GetMbmsgi01(string arg0)
        {
            if (arg0 == null) {
                throw new ArgumentException("\bh[GetMbmsgi01]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            return "[MBMSGI01] bZ[W`ID[" + arg0 + "]̃pbP[Ww肳Ă܂B";
        }

        /// <summary>bZ[W`ID[BlancoMessage]AL[[MBMSGI02]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.3: </newpara>
        /// <newpara>[T|[gȂo̓vO~Oꏈn[{0}]w肳܂B]</newpara>
        /// </remarks>
        /// <param name="arg0">u{0}̒lB</param>
        /// <returns>bZ[WB</returns>
        public string GetMbmsgi02(string arg0)
        {
            if (arg0 == null) {
                throw new ArgumentException("\bh[GetMbmsgi02]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            return "[MBMSGI02] T|[gȂo̓vO~Oꏈn[" + arg0 + "]w肳܂B";
        }

        /// <summary>bZ[W`ID[BlancoMessage]AL[[MBMSGI03]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.4: </newpara>
        /// <newpara>[bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B]</newpara>
        /// </remarks>
        /// <param name="arg0">u{0}̒lB</param>
        /// <param name="arg1">u{1}̒lB</param>
        /// <returns>bZ[WB</returns>
        public string GetMbmsgi03(string arg0, string arg1)
        {
            if (arg0 == null) {
                throw new ArgumentException("\bh[GetMbmsgi03]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg1 == null) {
                throw new ArgumentException("\bh[GetMbmsgi03]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            return "[MBMSGI03] bZ[W`ID[" + arg0 + "]ɂāAL[[" + arg1 + "]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B";
        }

        /// <summary>bZ[W`ID[BlancoMessage]AL[[MBMSGI04]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.5: </newpara>
        /// <newpara>[bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB]</newpara>
        /// </remarks>
        /// <param name="arg0">u{0}̒lB</param>
        /// <param name="arg1">u{1}̒lB</param>
        /// <param name="arg2">u{2}̒lB</param>
        /// <param name="arg3">u{3}̒lB</param>
        /// <returns>bZ[WB</returns>
        public string GetMbmsgi04(string arg0, string arg1, string arg2, string arg3)
        {
            if (arg0 == null) {
                throw new ArgumentException("\bh[GetMbmsgi04]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg1 == null) {
                throw new ArgumentException("\bh[GetMbmsgi04]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg2 == null) {
                throw new ArgumentException("\bh[GetMbmsgi04]̃p[^[arg2]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg3 == null) {
                throw new ArgumentException("\bh[GetMbmsgi04]̃p[^[arg3]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            return "[MBMSGI04] bZ[W`ID[" + arg0 + "]ɂāAL[[" + arg1 + "]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[" + arg2 + "]ƃ\[XohƂĔfꍇ̒ǔ[" + arg3 + "]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB";
        }

        /// <summary>bZ[W`ID[BlancoMessage]AL[[MBMSGA01]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.8: </newpara>
        /// <newpara>[^fBNg[{0}]݂܂B]</newpara>
        /// </remarks>
        /// <param name="arg0">u{0}̒lB</param>
        /// <returns>bZ[WB</returns>
        public string GetMbmsga01(string arg0)
        {
            if (arg0 == null) {
                throw new ArgumentException("\bh[GetMbmsga01]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            return "[MBMSGA01] ^fBNg[" + arg0 + "]݂܂B";
        }
    }
}

==> blancoMessage-0.5.6-src.zip: blancoMessage/blanco.cs/main/blanco/message/message/BlancoMessageMessage.cs <==
// ̃\[XR[h blanco FrameworkɂĎĂ܂B
using System;

namespace blanco.message.message
{
    /// <summary>blancoMessageIɗp郁bZ[WNXłB</summary>
    public class BlancoMessageMessage
    {
        /// <summary>[bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B]</summary>
        /// <remarks>
        /// <newpara>No.2: </newpara>
        /// </remarks>
        public static readonly string MBMSGI01 = "[MBMSGI01] bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B";

        /// <summary>[T|[gȂo̓vO~Oꏈn[{0}]w肳܂B]</summary>
        /// <remarks>
        /// <newpara>No.3: </newpara>
        /// </remarks>
        public static readonly string MBMSGI02 = "[MBMSGI02] T|[gȂo̓vO~Oꏈn[{0}]w肳܂B";

        /// <summary>[bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B]</summary>
        /// <remarks>
        /// <newpara>No.4: </newpara>
        /// </remarks>
        public static readonly string MBMSGI03 = "[MBMSGI03] bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B";

        /// <summary>[bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB]</summary>
        /// <remarks>
        /// <newpara>No.5: </newpara>
        /// </remarks>
        public static readonly string MBMSGI04 = "[MBMSGI04] bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB";

        /// <summary>[^fBNg[{0}]݂܂B]</summary>
        /// <remarks>
        /// <newpara>No.8: </newpara>
        /// </remarks>
        public static readonly string MBMSGA01 = "[MBMSGA01] ^fBNg[{0}]݂܂B";

        /// <summary>bZ[W`ID[BlancoMessage]AL[[MBMSGI01]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.2: </newpara>
        /// <newpara>[bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B]</newpara>
        /// </remarks>
        /// <param name="arg0">u{0}̒lB</param>
        /// <returns>bZ[WB</returns>
        public virtual string GetMbmsgi01(string arg0)
        {
            if (arg0 == null) {
                throw new ArgumentException("\bh[GetMbmsgi01]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            return "[MBMSGI01] bZ[W`ID[" + arg0 + "]̃pbP[Ww肳Ă܂B";
        }

        /// <summary>bZ[W`ID[BlancoMessage]AL[[MBMSGI02]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.3: </newpara>
        /// <newpara>[T|[gȂo̓vO~Oꏈn[{0}]w肳܂B]</newpara>
        /// </remarks>
        /// <param name="arg0">u{0}̒lB</param>
        /// <returns>bZ[WB</returns>
        public virtual string GetMbmsgi02(string arg0)
        {
            if (arg0 == null) {
                throw new ArgumentException("\bh[GetMbmsgi02]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            return "[MBMSGI02] T|[gȂo̓vO~Oꏈn[" + arg0 + "]w肳܂B";
        }

        /// <summary>bZ[W`ID[BlancoMessage]AL[[MBMSGI03]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.4: </newpara>
        /// <newpara>[bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B]</newpara>
        /// </remarks>
        /// <param name="arg0">u{0}̒lB</param>
        /// <param name="arg1">u{1}̒lB</param>
        /// <returns>bZ[WB</returns>
        public virtual string GetMbmsgi03(string arg0, string arg1)
        {
            if (arg0 == null) {
                throw new ArgumentException("\bh[GetMbmsgi03]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg1 == null) {
                throw new ArgumentException("\bh[GetMbmsgi03]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            return "[MBMSGI03] bZ[W`ID[" + arg0 + "]ɂāAL[[" + arg1 + "]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B";
        }

        /// <summary>bZ[W`ID[BlancoMessage]AL[[MBMSGI04]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.5: </newpara>
        /// <newpara>[bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB]</newpara>
        /// </remarks>
        /// <param name="arg0">u{0}̒lB</param>
        /// <param name="arg1">u{1}̒lB</param>
        /// <param name="arg2">u{2}̒lB</param>
        /// <param name="arg3">u{3}̒lB</param>
        /// <returns>bZ[WB</returns>
        public virtual string GetMbmsgi04(string arg0, string arg1, string arg2, string arg3)
        {
            if (arg0 == null) {
                throw new ArgumentException("\bh[GetMbmsgi04]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg1 == null) {
                throw new ArgumentException("\bh[GetMbmsgi04]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg2 == null) {
                throw new ArgumentException("\bh[GetMbmsgi04]̃p[^[arg2]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg3 == null) {
                throw new ArgumentException("\bh[GetMbmsgi04]̃p[^[arg3]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            return "[MBMSGI04] bZ[W`ID[" + arg0 + "]ɂāAL[[" + arg1 + "]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[" + arg2 + "]ƃ\[XohƂĔfꍇ̒ǔ[" + arg3 + "]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB";
        }

        /// <summary>bZ[W`ID[BlancoMessage]AL[[MBMSGA01]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.8: </newpara>
        /// <newpara>[^fBNg[{0}]݂܂B]</newpara>
        /// </remarks>
        /// <param name="arg0">u{0}̒lB</param>
        /// <returns>bZ[WB</returns>
        public virtual string GetMbmsga01(string arg0)
        {
            if (arg0 == null) {
                throw new ArgumentException("\bh[GetMbmsga01]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            return "[MBMSGA01] ^fBNg[" + arg0 + "]݂܂B";
        }
    }
}
